# AIworker_graph

控制和转换graph格式的Underlying capability
用来提供各种graph之间的转换能力


## 常规操作

### 导出环境
```
uv export --format requirements-txt > requirements.txt
```
### 更新文档
```
mkdocs serve # 预览
mkdocs gh-deploy # 同步到github网站
```

### 运行测试并同步到测试服务
```
bash run_test.sh
```